#
# spec file for package schismtracker
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           schismtracker
Version:        20250208
Release:        1.1
Summary:        Music editor that matches the look and feel of Impulse Tracker
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://schismtracker.org/
Source:         https://github.com/schismtracker/schismtracker/archive/refs/tags/%version.tar.gz
Source2:        %name.desktop
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  python3-base
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(libutf8proc)
BuildRequires:  pkgconfig(sdl2)

%description
Schism Tracker is a reimplementation of Impulse Tracker, a
program used to create music without the requirements of
specialized, expensive equipment, and with a unique "finger feel"
that is difficult to replicate in-part. The player is based on a
modified version of the Modplug engine, with a number of
bugfixes and changes to improve IT playback.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure
%make_build

%install
b="%buildroot"
%make_install
for size in 16 22 24 32 36 48 64 72 96 128 192; do
	install -Dm 0644 "icons/schism-icon-$size.png" \
		"$b/%_datadir/icons/hicolor/${size}x$size/apps/%name.png"
done
install -Dm 0644 icons/schism-icon.svg \
	"$b/%_datadir/icons/hicolor/scalable/apps/%name.svg"
%fdupes %buildroot/%_prefix
# install desktop file
%suse_update_desktop_file -i %name

%files
%license COPYING
%doc NEWS README.md
%_bindir/schismtracker
%_datadir/icons/hicolor
%_datadir/applications/*
%_datadir/pixmaps/*
%_mandir/man*/*

%changelog
* Sun Feb  9 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 20250208
  * Fix incorrect handling of Note Cuts (caused some super weird
    changes in playback)
  * Fix clicking with Note Cut DNAs
  * Fix saving stereo and 16-bit XI files
  * Fix importing and exporting AIFF files (sample rate was
    always zero)
  * Fix the Alt-F12 page and spectrum visualizer having weird
    holes in them
  * MOD/XM: Load A0F and AF0 as D0E and DE0 respectively to work
    around playback differences
* Thu Feb  6 2025 Bernhard Wiedemann <bwiedemann@suse.de>
- Drop schism-nodate.diff to make builds reproducible (boo#1047218)
* Wed Feb  5 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 20250202
  * MOD saving supports more than four channels now.
  * Floating point WAV/AIFF/AU importing now uses hardware
    floating point numbers, if available.
  * Fix note cut being cut off immediately regardless of whether
    ramping was enabled or not.
  * Fix envelope carry being dependent on a previous Note Off.
  * Fix a crash when loading some extremely large files.
* Fri Dec 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20241226
  * Implement Time Information page (accessible via
    LShift-LAlt-RAlt-RCtrl-Pause, or the more sane keybind
    Ctrl-Alt-T)
  * Implement OpenMPT-style loop wrap-around buffer (addresses
    playback issues with sample loops + interpolation)
  * Much more accurate VU meters in the info page
  * Fix handling of Lxx effects
  * Fix handling of S7B/S7C effects
  * Add support for 32-bit audio output
  * Add primitive info reader of EdLib Tracker EDL and D00 files
    (loading of the song data is not currently implemented)
  * Fix some AIFF and WAV files not being loaded properly
  * The default audio sample rate is now 48kHz instead of 44.1kHz
  * Instruments Page: Keyjazz now works like Impulse Tracker did
  * S3M: Import edit timers from Impulse Tracker and OpenMPT
  * S3M: Save Impulse Tracker-style edit timers
- Delete 0001-build-resolve-Wreturn-type-warnings.patch (merged)
* Mon Oct 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20241021
  * Fix search on the Load Module page
  * Wii U support
  * Fix portamento in both volume and effect column at the same
    time
  * Allow importing of IEEE floating point WAV and AU files
  * POSIX: Use ~/.config/schism by default; ~/.schism is used if
    it is available as a fallback
  * MIDI/JACK: Both midi in and out should work flawlessly now
  * S3M: Fix sample import under big endian architectures
  * IT: Fix V81-VFF commands in old Schism Tracker ITs
  * XM: Import ModPlug Tracker Command X extensions
- Add 0001-build-resolve-Wreturn-type-warnings.patch
* Tue Sep 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240909
  * Add new Unicode fonts (extended latin alphabet, Greek alphabet,
    and Hiragana) that are used in the sample, instrument, and
    module loading pages for filenames.
  * Better tracker detection for S3M files
  * More accurate import of the XM K00 effect
  * Rework cursor drawing to be more accurate to Impulse Tracker
  * Import panning on DSM files
  * Fix many possible memory leaks
  * S3M: don't warn about invalid notes when saving empty pattern
    cells
* Sun Jun 30 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240630
  * Add DSM format loader (thanks @RepellantMold)
  * Fix a crash upon loading some IT modules made in Modplug and
    its derivatives
- Delete schism-deptrack.diff, delete compile.diff (merged)
* Sat Jun 15 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240614
  * Add STX module importing
  * Add an audio device and driver selection widget in the
    Shift-F5 menu
- Delete schism-alsa.diff (obsolete), add compile.diff.
* Sun Jun  9 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240609
  * Fix saving 16-bit and/or stereo FLAC samples
  * Attempt to convert song messages from Modplug/OpenMPT IT
    files.
  * Expand the file and directory listings in the Load/Save
    Module screens to actually make use of wasted space. It
    didn't even look like IT did anyway.
  * File listings should now support paths with Unicode out of
    the box and will fall back to interpreting the raw characters
    if that fails.
  * Reimplement key repeat configuration
  * Allow copying and pasting palette settings to the clipboard
    and actually save them when applied
  * Fix saving the module's Schism version
  * Fix issues with the implementation that would have caused
    it to break after the Epochalypse
- Delete 0001-build-fix-gcc-warning-for-handle_text_input-function.patch
  (merged)
* Wed May 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240529
  * Add support for exporting songs and saving samples to FLAC
  * Fix mouse wheel coordinates getting warped under want_fixed=1
  * Fix some text input events causing global key inputs
  * Fix character digraphs
  * Fix double mouse cursor over half-width characters
  * Fix Shift-Tab not being the same as in ImpulseTracker
  * Fix appearance of parent directories in file browsers when
    those directories do, in fact, not exist
- Add 0001-build-fix-gcc-warning-for-handle_text_input-function.patch
* Sat May 25 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240523
  * Fix an issue where F4 would silence all samples when in sample mode
- Remove 0001-player-fx-check-for-Instrument-Mode-when-handling-No.patch
  (merged)
* Fri May 17 2024 Jan Engelhardt <jengelh@inai.de>
- Add 0001-player-fx-check-for-Instrument-Mode-when-handling-No.patch
* Thu May 16 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240515
  * XM: Improve import routines, autovibrato is now handled
    properly.
  * STM: More sane import for tempo, similar to OpenMPT.
  * S3M: Approximate the SAx command.
  * Replayer: Correct playback when a sample sustains after a
    portamento.
  * Replayer: Emulate IT when an instrument is triggered with a
    note that does not map to any sample.
* Sun May  5 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240503
  * Add initial JACK-MIDI support.
  * Fix handling of instrument + tone portamento while in
    Compatible Gxx mode.
  * Warn on nonfunctional MIDI processing.
  * When loading .669 files, reset the effects list on a new note.
* Sat Apr 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240426
  * Properly load samples from .stm files
  * Fix a bug where any forced panning on an instrument would be
    lost upon triggering a new note
  * Make the instrument list's behavior when pressing space on an
    instrument match the help list information
  * Fix playing instruments in the instrument list
* Tue Apr  9 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240409
  * Remove unnecessary video code
* Fri Mar 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240328
  * Fix entering line breaks into the message editor
  * Don't abort when IT files report an order list size over 256
* Sun Mar 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240308
  * Use native text input handlers rather than emulating SDL 1.2
    APIs, which should allow for a smoother experience for locales
    other than en_US.
  * Fixed panbrello implementation
  * Fixed a player bug that implemented NNA incorrectly
  * Clear MIDI macros if a file is made with Impulse Tracker 2.14,
    not when it declares to be compatible with it.
* Mon Jan 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240129
  * Provide undo for "revert pattern data"
  * Fixed a playback bug where an instrument's volume is zero and
    has gotten a note off would not trigger the envelopes properly
  * Fixed a playback bug where Position Jumps and Pattern Breaks
    would not work sometimes
* Sun Oct 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2013102
  * Fixed many OpenMPT test cases, which can (and will) break some
    older modules.
  * Remove many old flags that were not considered very useful.
* Thu Sep  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230906
  * Add FLAC loading support
  * Fix improper playback of note-without-instrument after
    instrument-without-note
  * Fix for initial instrument-without-note
  * MIDI note-off events that don't match the last note are now dropped
  * Detect S3M files made with Graoumf Tracker
* Thu Dec  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221201
  * Fix issues when reverting to a previous video (mode)
    interpolation setting
* Thu Oct 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221020
  * Fix duplicated key input in pattern editor, order list, and
    instrument editor note table
  * Respect audio-related SDL environment variables if set
  * Fix handling of window width and height config file options
  * Hint SDL not to disable window manager compositing
  * Add 4:3 aspect ratio config file option (want_fixed)
* Mon Sep  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220905
  * Windows fixes only
* Sun Aug  7 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220807
  * Use SDL2 instead of SDL1.2. This fixes various
    platform-dependent issues with video code, adds support for
    new audio drivers such as JACK, and removes the System
    Configuration video driver choices in favor of video scaling
    method selection.
  * Fix multitrack mono audio export.
  * Support ADPCM and stereo samples in XM files.
- Drop 0001-configure.ac-Accept-SDL-1.2.50.patch
* Wed Jun 22 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-configure.ac-Accept-SDL-1.2.50.patch
* Tue May 17 2022 Jan Engelhardt <jengelh@inai.de>
- Employ pkgconfig(sdl) to allow pulling in sdl12_compat.
* Fri May  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220506
  * Fix import of EBF volume slides from MOD/XM files
  * Fix various multisample instrument bugs
* Thu Apr 21 2022 Dirk Müller <dmueller@suse.com>
- update to 20220125:
  * Release builds now support macOS 10.9+ (previously supported only 10.15+)
  * Fix window size on high-DPI macOS displays when launched from app bundle
  * Fix reading of various meta events in MIDI files
  * Fix IMF filter envelope being upside down and IMF disable envelope command
  * Fix bug in AIFF multi-write
- schism-deptrack.diff: refresh
* Wed Nov 17 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211116
  * Reset filter when previewing different instrments
  * Fix ST3 GUS/SB detection on big-endian platforms
* Mon Nov 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211115
  * Add warning for lost patterns when saving MOD files
  * Fix S3M tracker identification bug
  * Add support for reading OPL instruments from MPTM files
  * Allow loading ModPlug volume column panning in S3M files
  * Reset mixing volume to 48 for S3Ms made with GUS
  * Strip zero-param commands that only have memory in IT from
    MOD/XM files when loading
  * Fix depth of instrument pitch-pan separation
  * Fix incorrect position calculation after reaching end of
    ping-pong loops
  * Add rudimentary detection for SoundTracker MODs in file browser
  * Apply pitch/pan separation as part of instrument panning
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210525
  * Add support for saving MOD files
  * Fix conflict in MIDI setup when ALSA and OSS are both available
  * Fix instrument and sample panning overwriting channel panning
  * Fix issues related to portamento with Amiga slides
  * Support compressed stereo samples in ITI/ITS files
  * Convert XM/MOD EA0/EB0 to D00 when loading
  * Fix memory access bug in the MTM loader
* Thu Jul  2 2020 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to new upstream release 20200412
  * Fix problem with switching tabs on the Instrument List page using the keyboard, introduced in 20190722 release.
  * Implement incremental search on Load Instrument page, like on the Load Sample and Load Module pages.
  * Correctly display size of exported mono files before exporting.
  * Add "AudioVideo" category to Linux desktop entry.
* Sun Aug 18 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 20190805
  * fixed CVE-2019-14524 [boo#1144261]: heap overflow in
    MTM loader
  * fixed CVE-2019-14523 [boo#1144266]: heap overflow in
    Oktalyzer loader
  * support 15-channel MOD files
  * Support undocumented MIDI macro characters, and support
    character p (MIDI program) properly.
* Thu Feb  8 2018 jengelh@inai.de
- Get rid of BuildRequires: xorg-x11-devel.
* Wed Feb  7 2018 jengelh@inai.de
- Update to new upstream release 20170910
  * Make MIDI note entry reliable
  * Stop restricting instrument in MIDI note entry based on MIDI
    channel (this was nonsense)
  * Fix note off events in MIDI output
  * Improve S3M AdLib emulation
  * Allow navigating the Load Instrument screen by holding up or
    down, just like on the Load Sample and Load Module screens
  * Support ADPCM samples in MOD files
  * Detect Cheesetracker and old OpenMPT modules
* Thu Apr  9 2015 jengelh@inai.de
- Update to new snapshot 20150409
  * ping-pong effect was wrongly mixed together
  * support for loading 24-bit stereo WAV samples
  * use OpenMPT filters
* Sun Oct  5 2014 jengelh@inai.de
- Update to new snapshot 20140419
  * reset panning after S91 if sample/instrument has a default
  panning set
  * add timestamp sorting mode; hide *~ on all platforms
  * re-add note fade when hitting end of unlooped volume envelope
* Wed Feb  8 2012 jengelh@medozas.de
- Update to new upstream release 20120105
  * Shift-F10 now provides a dialog if the orderlist is empty
  * Fix loop points when deleting last point in envelope
  * Instrument list: Alt-Shift-A on trans table now copies sample
  name as well as assigning sample numbers
  * Less picky sample-replacement checking for pattern-to-sample
  rendering
  * Pattern editor: enter key now does channel search for instrument
  number if none is under the cursor
  * Add hidden option for inverted (more FT2-like) home/end key
  behavior in the pattern editor
  * Fix garbage writing when swapping portamento to the volume column
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep 29 2011 idonmez@suse.com
- Add schismtracker-link.patch to link with new ld
* Sat Apr  9 2011 jengelh@medozas.de
- updated to Hg snapshot 20110409
- removed __DATE__/__TIME__ from source (via patch)
* Mon Aug 30 2010 jengelh@medozas.de
- Add a patch to schismtracker that restores sound for
  sound chips that lack hardware mixing capabilities.
* Wed Feb 24 2010 prusnak@suse.cz
- renamed to schismtracker
* Wed Feb 24 2010 jengelh@medozas.de
- updated to Hg snapshot 20100224
* Tue Dec 11 2007 prusnak@suse.cz
- updated to CVS snapshot 20071208
* Thu Nov  1 2007 prusnak@suse.cz
- added desktop and icon files
* Tue Sep 18 2007 prusnak@suse.cz
- created package (initial version 0.4.99.1 = 0.5rc1)
